function [w1,K1] = map_F_u(w,K,u,mu) ;

% 2D "periapsis kick" map with control 
%
% From an approximation of the restricted three-body problem which approximates
% the effect of perturbations by the smaller mass on orbital elements (where
% the orbital elements approximate a Kepler ellipse about the larger mass)
% 
% The map is from Picard's method over one ellipse from apoapsis to apoapsis
%
% Map F takes the angle of peripase (w) and Keplerian energy (K),
% and a small control (u), representing the "Delta-V" at periapse, which can
% be positive or negative, 
% and yields the changed values (w1,K1) 
%
% The mass parameter mu, Jacobi constant CJ, and abar are parameters of the map.  
%
% Yields trajectories,
%
% ((w_0,K_0),(w_1,K_1),...,(w_n,K_n))
%
% mu is the measure of the perturbation (mu=0 for no perturbation)
% mu=0 case leads to "invariant circles", lines of constant K
%
% Shane Ross
% shaneross.com
% May 2006

warning off MATLAB:fzero:UndeterminedSyntax

global II alpha

% f is the energy kick function
f = -Rintegral(w) +sin(w)* II  ; 

K1 = K + mu*f + alpha*u;		
w1 = w - 2*pi*(-2*K1)^(-3/2) ;
