setup_map_F_u 	% obtains global variables

% obtain N iterates of the map f where (w(1),rKa(1)) is the initial condition
N = 19 ;

w=[];K=[];


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% initial conditions for example run`
w(1) = 0.0084664*pi ; % initial angle of periapse (in radians)
a0   = 1.54 ; % initial semimajor axis (in units of Jupiter-moon distance)
K(1) =-0.5/a0 ; % initial Keplerian energy
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% control u \in [-u_max,u_max], where 0 < u_max << 1
% u_max given in setup_map_f_u

%u =u_max*(ones(1,N)-2*rand(1,N)); 	% random control
u =0.5*u_max*ones(1,N) ; 			% always constant control
u(5)=-2.43*u_max ;
u(10)=+5.0*u_max ;
u(12)=-0.54*u_max ;
u(19)=0*u_max ;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compute controlled trajectory
for k = 1:N-1,
  [w(k+1),K(k+1)] = map_F_u(w(k),K(k),u(k), mu) ;
  w(k+1) = modw(w(k+1)) ; % gives angle mod 2*pi and between -pi and pi
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Load exit to capture realm around smaller mass
exit = load('target_w_K.dat') ;     % The 'exit' is the first (backward) 
                                    % intersection of stable 
                                    % manifold of L2 Lyapunov orbit,
                                    % computed by other means.  Any
                                    % trajectory reaching the exit will the
                                    % domain of the map and enter the
                                    % capture realm around the smaller mass
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plot resulting trajectory along with exit
h=plot(w/pi,K,'r.-',w(1)/pi,K(1),'r>',w(N)/pi,K(N),'rs') ;
%set(h,'linewidth',3,'markersize',8);
axis([-1 1 -0.4630 -0.2778]) ;
hold on
fill(exit(:,1)/pi,exit(:,2),'c');
%xlabel('w'); ylabel('a');
xlabel('\omega/\pi'); ylabel('K');
title('Example trajectory in (\omega/\pi,K) coordinates: start (triangle) and end (square)');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compute cost function for trajectory to minimize

% c = compromise parameter between fuel and time optimization
% c = 0 to compute only fuel, c = 1 to compute time only

c = 1 ; 
A = 1/u_max ;
B = 1/(2*pi);
for n=1:N
  g(n) = (1-c)*A*abs(u(n)) + c*B*(-0.5/K(n))^(3/2) ; % preferred
 %g(n) = (1-c)*A*u(n)^2    + c*B*(-0.5/K(n))^(3/2) ; % if g must be differentiable
end

TOTALCOST = sum(g) ;

disp(['Total cost: ' num2str(TOTALCOST)]) ;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Draw trajectory in m1-centered inertial frame
figure
draw_ellipses
title('Example trajectory in m1-centered inertial frame position space (unit circle is orbit of m2)');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%